% Auto-generated chapter 87 for bukhari
% Hadiths in this chapter: 55

\hadithdefcmd{bukhari}{6861}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَمْرِو بْنِ شُرَحْبِيلَ، قَالَ قَالَ عَبْدُ اللَّهِ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَىُّ الذَّنْبِ أَكْبَرُ عِنْدَ اللَّهِ قَالَ ‏"‏ أَنْ تَدْعُوَ لِلَّهِ نِدًّا، وَهْوَ خَلَقَكَ ‏"‏‏.‏ قَالَ ثُمَّ أَىٌّ قَالَ ‏"‏ ثُمَّ أَنْ تَقْتُلَ وَلَدَكَ، أَنْ يَطْعَمَ مَعَكَ ‏"‏‏.‏ قَالَ ثُمَّ أَىٌّ قَالَ ‏"‏ ثُمَّ أَنْ تُزَانِيَ بِحَلِيلَةِ جَارِكَ ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ تَصْدِيقَهَا ‏\{‏وَالَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ وَلاَ يَقْتُلُونَ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ وَلاَ يَزْنُونَ وَمَنْ يَفْعَلْ ذَلِكَ‏ يَلْقَ أَثَامًا\}‏ الآيَةَ‏.‏\hadithno{6861}\hadithtrans{Narrated `Abdullah:A man said, "O Allah's Messenger (ﷺ)! Which sin is the greatest in Allah's Sight?" The Prophet (ﷺ) said, "To set up a rival unto Allah though He Alone created you . " The man said, "What is next?" The Prophet (ﷺ) said, "To kill your son lest he should share your food with you." The man said, "What is next?" The Prophet said, "To commit illegal sexual intercourse with the wife of your neighbor." So Allah revealed in confirmation of this narration:-- 'And those who invoke not with Allah, any other god. Nor kill, such life as Allah has forbidden except for just cause nor commit illegal sexual intercourse. And whoever does this shall receive the punishment}}
\hadithdefcmd{bukhari}{6862}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا إِسْحَاقُ بْنُ سَعِيدِ بْنِ عَمْرِو بْنِ سَعِيدِ بْنِ الْعَاصِ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَنْ يَزَالَ الْمُؤْمِنُ فِي فُسْحَةٍ مِنْ دِينِهِ، مَا لَمْ يُصِبْ دَمًا حَرَامًا ‏"‏‏.‏\hadithno{6862}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "A faithful believer remains at liberty regarding his religion unless he kills somebody unlawfully}}
\hadithdefcmd{bukhari}{6863}{حَدَّثَنِي أَحْمَدُ بْنُ يَعْقُوبَ، حَدَّثَنَا إِسْحَاقُ، سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ إِنَّ مِنْ وَرْطَاتِ الأُمُورِ الَّتِي لاَ مَخْرَجَ لِمَنْ أَوْقَعَ نَفْسَهُ فِيهَا، سَفْكَ الدَّمِ الْحَرَامِ بِغَيْرِ حِلِّهِ‏.‏\hadithno{6863}\hadithtrans{Narrated `Abdullah bin `Umar:One of the evil deeds with bad consequence from which there is no escape for the one who is involved in it is to kill someone unlawfully}}
\hadithdefcmd{bukhari}{6864}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَوَّلُ مَا يُقْضَى بَيْنَ النَّاسِ فِي الدِّمَاءِ ‏"‏‏.‏\hadithno{6864}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "The first cases to be decided among the people (on the Day of Resurrection) will be those of blood-shed}}
\hadithdefcmd{bukhari}{6866}{حَدَّثَنَا عَبْدَانُ، حَدَّثَنَا عَبْدُ اللَّهِ، حَدَّثَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، حَدَّثَنَا عَطَاءُ بْنُ يَزِيدَ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَدِيٍّ، حَدَّثَهُ أَنَّ الْمِقْدَادَ بْنَ عَمْرٍو الْكِنْدِيَّ حَلِيفَ بَنِي زُهْرَةَ حَدَّثَهُ وَكَانَ، شَهِدَ بَدْرًا مَعَ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ إِنْ لَقِيتُ كَافِرًا فَاقْتَتَلْنَا، فَضَرَبَ يَدِي بِالسَّيْفِ فَقَطَعَهَا، ثُمَّ لاَذَ بِشَجَرَةٍ وَقَالَ أَسْلَمْتُ لِلَّهِ‏.‏ آقْتُلُهُ بَعْدَ أَنْ قَالَهَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَقْتُلْهُ ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ فَإِنَّهُ طَرَحَ إِحْدَى يَدَىَّ، ثُمَّ قَالَ بَعْدَ مَا قَطَعَهَا، آقْتُلُهُ قَالَ ‏"‏ لاَ تَقْتُلْهُ، فَإِنْ قَتَلْتَهُ فَإِنَّهُ بِمَنْزِلَتِكَ قَبْلَ أَنْ تَقْتُلَهُ، وَأَنْتَ بِمَنْزِلَتِهِ قَبْلَ أَنْ يَقُولَ كَلِمَتَهُ الَّتِي قَالَ ‏"‏‏.‏ وَقَالَ حَبِيبُ بْنُ أَبِي عَمْرَةَ عَنْ سَعِيدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم لِلْمِقْدَادِ ‏"‏ إِذَا كَانَ رَجُلٌ مُؤْمِنٌ يُخْفِي إِيمَانَهُ مَعَ قَوْمٍ كُفَّارٍ، فَأَظْهَرَ إِيمَانَهُ، فَقَتَلْتَهُ، فَكَذَلِكَ كُنْتَ أَنْتَ تُخْفِي إِيمَانَكَ بِمَكَّةَ مِنْ قَبْلُ ‏"‏‏.‏\hadithno{6866}\hadithtrans{Narrated Al-Miqdad bin `Amr Al-Kindi:An ally of Bani Zuhra who took part in the battle of Badr with the Prophet, that he said, "O Allah's Apostle! If I meet an unbeliever and we have a fight, and he strikes my hand with the sword and cuts it off, and then takes refuge from me under a tree, and says, 'I have surrendered to Allah (i.e. embraced Islam),' may I kill him after he has said so?" Allah's Messenger (ﷺ) said, "Do not kill him." Al- Miqdad said, "But O Allah's Messenger (ﷺ)! He had chopped off one of my hands and he said that after he had cut it off. May I kill him?" The Prophet (ﷺ) said. "Do not kill him for if you kill him, he would be in the position in which you had been before you kill him, and you would be in the position in which he was before he said the sentence." The Prophet (ﷺ) also said to Al-Miqdad, "If a faithful believer conceals his faith (Islam) from the disbelievers, and then when he declares his Islam, you kill him, (you will be sinful). Remember that you were also concealing your faith (Islam) at Mecca before}}
\hadithdefcmd{bukhari}{6867}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُقْتَلُ نَفْسٌ إِلاَّ كَانَ عَلَى ابْنِ آدَمَ الأَوَّلِ كِفْلٌ مِنْهَا ‏"‏‏.‏\hadithno{6867}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "No human being is killed unjustly, but a part of responsibility for the crime is laid on the first son of Adam who invented the tradition of killing (murdering) on the earth. (It is said that he was Qabil)}}
\hadithdefcmd{bukhari}{6868}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، قَالَ وَاقِدُ بْنُ عَبْدِ اللَّهِ أَخْبَرَنِي عَنْ أَبِيهِ، سَمِعَ عَبْدَ اللَّهِ بْنَ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَرْجِعُوا بَعْدِي كُفَّارًا يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏‏.‏\hadithno{6868}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) said, "After me (i.e. after my death), do not become disbelievers, by striking (cutting) the necks of one another}}
\hadithdefcmd{bukhari}{6869}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَلِيِّ بْنِ مُدْرِكٍ، قَالَ سَمِعْتُ أَبَا زُرْعَةَ بْنَ عَمْرِو بْنِ جَرِيرٍ، عَنْ جَرِيرٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ ‏ "‏ اسْتَنْصِتِ النَّاسَ، لاَ تَرْجِعُوا بَعْدِي كُفَّارًا يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏‏.‏ رَوَاهُ أَبُو بَكْرَةَ وَابْنُ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6869}\hadithtrans{Narrated Abu Zur'a bin `Amr bin Jarir:The Prophet (ﷺ) said during Hajjat-al-Wada`, "Let the people be quiet and listen to me. After me, do not become disbelievers, by striking (cutting) the necks of one another}}
\hadithdefcmd{bukhari}{6870}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ فِرَاسٍ، عَنِ الشَّعْبِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ الْكَبَائِرُ الإِشْرَاكُ بِاللَّهِ، وَعُقُوقُ الْوَالِدَيْنِ ‏"‏‏.‏ أَوْ قَالَ ‏"‏ الْيَمِينُ الْغَمُوسُ ‏"‏‏.‏ شَكَّ شُعْبَةُ‏.‏ وَقَالَ مُعَاذٌ حَدَّثَنَا شُعْبَةُ قَالَ ‏"‏ الْكَبَائِرُ الإِشْرَاكُ بِاللَّهِ، وَالْيَمِينُ الْغَمُوسُ، وَعُقُوقُ الْوَالِدَيْنِ ‏"‏‏.‏ أَوْ قَالَ ‏"‏ وَقَتْلُ النَّفْسِ ‏"‏‏.‏\hadithno{6870}\hadithtrans{Narrated `Abdullah bin `Amr:The Prophet (ﷺ) said, "Al-Ka`ba'ir (the biggest sins) are: To join others (as partners) in worship with Allah, to be undutiful to one's parents," or said, "to take a false oath." (The sub-narrator, Shu`ba is not sure) Mu`adh said: Shu`ba said, "Al-Ka`ba'ir (the biggest sins) are: (1) Joining others as partners in worship with Allah, (2) to take a false oath (3) and to be undutiful to one's parents," or said, "to murder (someone unlawfully)}}
\hadithdefcmd{bukhari}{6871}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ أَبِي بَكْرٍ، سَمِعَ أَنَسًا ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ الْكَبَائِرُ ‏"‏‏.‏ وَحَدَّثَنَا عَمْرٌو حَدَّثَنَا شُعْبَةُ عَنِ ابْنِ أَبِي بَكْرٍ عَنْ أَنَسِ بْنِ مَالِكٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ أَكْبَرُ الْكَبَائِرِ الإِشْرَاكُ بِاللَّهِ وَقَتْلُ النَّفْسِ، وَعُقُوقُ الْوَالِدَيْنِ، وَقَوْلُ الزُّورِ ‏"‏‏.‏ أَوْ قَالَ ‏"‏ وَشَهَادَةُ الزُّورِ ‏"‏‏.‏\hadithno{6871}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "The biggest of Al-Ka`ba'ir (the great sins) are (1) to join others as partners in worship with Allah, (2) to murder a human being, (3) to be undutiful to one's parents (4) and to make a false statement," or said, "to give a false witness}}
\hadithdefcmd{bukhari}{6872}{حَدَّثَنَا عَمْرُو بْنُ زُرَارَةَ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا حُصَيْنٌ، حَدَّثَنَا أَبُو ظَبْيَانَ، قَالَ سَمِعْتُ أُسَامَةَ بْنَ زَيْدِ بْنِ حَارِثَةَ ـ رضى الله عنهما ـ يُحَدِّثُ قَالَ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْحُرَقَةِ مِنْ جُهَيْنَةَ ـ قَالَ ـ فَصَبَّحْنَا الْقَوْمَ فَهَزَمْنَاهُمْ ـ قَالَ ـ وَلَحِقْتُ أَنَا وَرَجُلٌ مِنَ الأَنْصَارِ رَجُلاً مِنْهُمْ ـ قَالَ ـ فَلَمَّا غَشِينَاهُ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ ـ قَالَ ـ فَكَفَّ عَنْهُ الأَنْصَارِيُّ، فَطَعَنْتُهُ بِرُمْحِي حَتَّى قَتَلْتُهُ ـ قَالَ ـ فَلَمَّا قَدِمْنَا بَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم قَالَ فَقَالَ لِي ‏"‏ يَا أُسَامَةُ أَقَتَلْتَهُ بَعْدَ مَا قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّمَا كَانَ مُتَعَوِّذًا‏.‏ قَالَ ‏"‏ أَقَتَلْتَهُ بَعْدَ أَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏‏.‏ قَالَ فَمَا زَالَ يُكَرِّرُهَا عَلَىَّ حَتَّى تَمَنَّيْتُ أَنِّي لَمْ أَكُنْ أَسْلَمْتُ قَبْلَ ذَلِكَ الْيَوْمِ‏.‏\hadithno{6872}\hadithtrans{Narrated Usama bin Zaid bin Haritha:Allah's Messenger (ﷺ) sent us (to fight) against Al-Huraqa (one of the sub-tribes) of Juhaina. We reached those people in the morning and defeated them. A man from the Ansar and I chased one of their men and when we attacked him, he said, "None has the right to be worshipped but Allah." The Ansari refrained from killing him but I stabbed him with my spear till I killed him. When we reached (Medina), this news reached the Prophet. He said to me, "O Usama! You killed him after he had said, 'None has the right to be worshipped but Allah?"' I said, "O Allah's Messenger (ﷺ)! He said so in order to save himself." The Prophet (ﷺ) said, "You killed him after he had said, 'None has the right to be worshipped but Allah." The Prophet (ﷺ) kept on repeating that statement till I wished I had not been a Muslim before that day}}
\hadithdefcmd{bukhari}{6873}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنَا يَزِيدُ، عَنْ أَبِي الْخَيْرِ، عَنِ الصُّنَابِحِيِّ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ ـ رضى الله عنه ـ قَالَ إِنِّي مِنَ النُّقَبَاءِ الَّذِينَ بَايَعُوا رَسُولَ اللَّهِ صلى الله عليه وسلم بَايَعْنَاهُ عَلَى أَنْ لاَ نُشْرِكَ بِاللَّهِ شَيْئًا، وَلاَ نَسْرِقَ وَلاَ نَزْنِيَ، وَلاَ نَقْتُلَ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ، وَلاَ نَنْتَهِبَ، وَلاَ نَعْصِيَ، بِالْجَنَّةِ إِنْ فَعَلْنَا ذَلِكَ، فَإِنْ غَشِينَا مِنْ ذَلِكَ شَيْئًا كَانَ قَضَاءُ ذَلِكَ إِلَى اللَّهِ‏.‏\hadithno{6873}\hadithtrans{Narrated 'Ubada bin As-Samat:I was among those Naqibs (selected leaders) who gave the Pledge of allegiance to Allah's Messenger (ﷺ). We gave the oath of allegiance, that we would not join partners in worship besides Allah, would not steal, would not commit illegal sexual intercourse, would not kill a life which Allah has forbidden, would not commit robbery, would not disobey (Allah and His Apostle), and if we fulfilled this pledge we would have Paradise, but if we committed any one of these (sins), then our case will be decided by Allah}}
\hadithdefcmd{bukhari}{6874}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَمَلَ عَلَيْنَا السِّلاَحَ فَلَيْسَ مِنَّا ‏"‏‏.‏ رَوَاهُ أَبُو مُوسَى عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6874}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "Whoever carries arms against us, is not from us}}
\hadithdefcmd{bukhari}{6875}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الْمُبَارَكِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا أَيُّوبُ، وَيُونُسُ، عَنِ الْحَسَنِ، عَنِ الأَحْنَفِ بْنِ قَيْسٍ، قَالَ ذَهَبْتُ لأَنْصُرَ هَذَا الرَّجُلَ، فَلَقِيَنِي أَبُو بَكْرَةَ فَقَالَ أَيْنَ تُرِيدُ قُلْتُ أَنْصُرُ هَذَا الرَّجُلَ‏.‏ قَالَ ارْجِعْ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِذَا الْتَقَى الْمُسْلِمَانِ بِسَيْفَيْهِمَا فَالْقَاتِلُ وَالْمَقْتُولُ فِي النَّارِ ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ هَذَا الْقَاتِلُ فَمَا بَالُ الْمَقْتُولِ قَالَ ‏"‏ إِنَّهُ كَانَ حَرِيصًا عَلَى قَتْلِ صَاحِبِهِ ‏"‏‏.‏\hadithno{6875}\hadithtrans{Narrated Al-Ahnaf bin Qais:I went to help that man (i.e., `Ali), and on the way I met Abu Bakra who asked me, "Where are you going?" I replied, "I am going to help that man." He said, "Go back, for I heard Allah's Messenger (ﷺ) saying, 'If two Muslims meet each other with their swords then (both) the killer and the killed one are in the (Hell) Fire.' I said, 'O Allah's Messenger (ﷺ)! It is alright for the killer, but what about the killed one?' He said, 'The killed one was eager to kill his opponent}}
\hadithdefcmd{bukhari}{6876}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ يَهُودِيًّا، رَضَّ رَأْسَ جَارِيَةٍ بَيْنَ حَجَرَيْنِ، فَقِيلَ لَهَا مَنْ فَعَلَ بِكِ هَذَا أَفُلاَنٌ أَوْ فُلاَنٌ حَتَّى سُمِّيَ الْيَهُودِيُّ، فَأُتِيَ بِهِ النَّبِيُّ صلى الله عليه وسلم فَلَمْ يَزَلْ بِهِ حَتَّى أَقَرَّ بِهِ، فَرُضَّ رَأْسُهُ بِالْحِجَارَةِ‏.‏\hadithno{6876}\hadithtrans{Narrated Anas bin Malik:A Jew crushed the head of a girl between two stones, and the girl was asked, "Who has done that to you, so-and-so or so and so?" (Some names were mentioned for her) till the name of that Jew was mentioned (whereupon she agreed). The Jew was brought to the Prophet (ﷺ) and the Prophet (ﷺ) kept on questioning him till he confessed, whereupon his head was crushed with stones}}
\hadithdefcmd{bukhari}{6877}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ شُعْبَةَ، عَنْ هِشَامِ بْنِ زَيْدِ بْنِ أَنَسٍ، عَنْ جَدِّهِ، أَنَسِ بْنِ مَالِكٍ قَالَ خَرَجَتْ جَارِيَةٌ عَلَيْهَا أَوْضَاحٌ بِالْمَدِينَةِ ـ قَالَ ـ فَرَمَاهَا يَهُودِيٌّ بِحَجَرٍ ـ قَالَ ـ فَجِيءَ بِهَا إِلَى النَّبِيِّ صلى الله عليه وسلم وَبِهَا رَمَقٌ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فُلاَنٌ قَتَلَكِ ‏"‏‏.‏ فَرَفَعَتْ رَأْسَهَا، فَأَعَادَ عَلَيْهَا قَالَ ‏"‏ فُلاَنٌ قَتَلَكِ ‏"‏‏.‏ فَرَفَعَتْ رَأْسَهَا، فَقَالَ لَهَا فِي الثَّالِثَةِ ‏"‏ فُلاَنٌ قَتَلَكِ ‏"‏‏.‏ فَخَفَضَتْ رَأْسَهَا، فَدَعَا بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَتَلَهُ بَيْنَ الْحَجَرَيْنِ‏.‏\hadithno{6877}\hadithtrans{Narrated Anas bin Malik:A girl wearing ornaments, went out at Medina. Somebody struck her with a stone. She was brought to the Prophet (ﷺ) while she was still alive. Allah's Messenger (ﷺ) asked her, "Did such-and-such a person strike you?" She raised her head, denying that. He asked her a second time, saying, "Did so-and-so strike you?" She raised her head, denying that. He said for the third time, "Did so-and-so strike you?" She lowered her head, agreeing. Allah's Messenger (ﷺ) then sent for the killer and killed him between two stones}}
\hadithdefcmd{bukhari}{6878}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ دَمُ امْرِئٍ مُسْلِمٍ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ إِلاَّ بِإِحْدَى ثَلاَثٍ النَّفْسُ بِالنَّفْسِ وَالثَّيِّبُ الزَّانِي، وَالْمَارِقُ مِنَ الدِّينِ التَّارِكُ الْجَمَاعَةَ ‏"‏‏.‏\hadithno{6878}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) said, "The blood of a Muslim who confesses that none has the right to be worshipped but Allah and that I am His Apostle, cannot be shed except in three cases: In Qisas for murder, a married person who commits illegal sexual intercourse and the one who reverts from Islam (apostate) and leaves the Muslims}}
\hadithdefcmd{bukhari}{6879}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ يَهُودِيًّا، قَتَلَ جَارِيَةً عَلَى أَوْضَاحٍ لَهَا، فَقَتَلَهَا بِحَجَرٍ، فَجِيءَ بِهَا إِلَى النَّبِيِّ صلى الله عليه وسلم وَبِهَا رَمَقٌ فَقَالَ ‏ "‏ أَقَتَلَكِ فُلاَنٌ ‏"‏‏.‏ فَأَشَارَتْ بِرَأْسِهَا أَنْ لاَ، ثُمَّ قَالَ الثَّانِيَةَ، فَأَشَارَتْ بِرَأْسِهَا أَنْ لاَ، ثُمَّ سَأَلَهَا الثَّالِثَةَ فَأَشَارَتْ بِرَأْسِهَا أَنْ نَعَمْ، فَقَتَلَهُ النَّبِيُّ صلى الله عليه وسلم بِحَجَرَيْنِ‏.‏\hadithno{6879}\hadithtrans{Narrated Anas:A Jew killed a girl so that he may steal her ornaments. He struck her with a stone, and she was brought to the Prophet (ﷺ) while she was still alive. The Prophet (ﷺ) asked her, "Did such-and-such person strike you?" She gestured with her head, expressing denial. He asked her for the second time, and she again gestured with her head, expressing denial. When he asked her for the third time, she beckoned, "Yes." So the Prophet (ﷺ) killed him (the Jew) with two stones}}
\hadithdefcmd{bukhari}{6880}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ خُزَاعَةَ، قَتَلُوا رَجُلاً‏.‏ وَقَالَ عَبْدُ اللَّهِ بْنُ رَجَاءٍ حَدَّثَنَا حَرْبٌ عَنْ يَحْيَى حَدَّثَنَا أَبُو سَلَمَةَ حَدَّثَنَا أَبُو هُرَيْرَةَ أَنَّهُ عَامَ فَتْحِ مَكَّةَ قَتَلَتْ خُزَاعَةُ رَجُلاً مِنْ بَنِي لَيْثٍ بِقَتِيلٍ لَهُمْ فِي الْجَاهِلِيَّةِ، فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنَّ اللَّهَ حَبَسَ عَنْ مَكَّةَ الْفِيلَ وَسَلَّطَ عَلَيْهِمْ رَسُولَهُ وَالْمُؤْمِنِينَ، أَلاَ وَإِنَّهَا لَمْ تَحِلَّ لأَحَدٍ قَبْلِي، وَلاَ تَحِلُّ لأَحَدٍ بَعْدِي، أَلاَ وَإِنَّمَا أُحِلَّتْ لِي سَاعَةً مِنْ نَهَارٍ، أَلاَ وَإِنَّهَا سَاعَتِي هَذِهِ حَرَامٌ لاَ يُخْتَلَى شَوْكُهَا، وَلاَ يُعْضَدُ شَجَرُهَا، وَلاَ يَلْتَقِطُ سَاقِطَتَهَا إِلاَّ مُنْشِدٌ، وَمَنْ قُتِلَ لَهُ قَتِيلٌ فَهْوَ بِخَيْرِ النَّظَرَيْنِ إِمَّا يُودَى وَإِمَّا يُقَادُ ‏"‏‏.‏ فَقَامَ رَجُلٌ مِنْ أَهْلِ الْيَمَنِ يُقَالُ لَهُ أَبُو شَاهٍ فَقَالَ اكْتُبْ لِي يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اكْتُبُوا لأَبِي شَاهٍ ‏"‏‏.‏ ثُمَّ قَامَ رَجُلٌ مِنْ قُرَيْشٍ فَقَالَ يَا رَسُولَ اللَّهِ إِلاَّ الإِذْخِرَ، فَإِنَّمَا نَجْعَلُهُ فِي بُيُوتِنَا وَقُبُورِنَا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِلاَّ الإِذْخِرَ ‏"‏‏.‏ وَتَابَعَهُ عُبَيْدُ اللَّهِ عَنْ شَيْبَانَ فِي الْفِيلِ، قَالَ بَعْضُهُمْ عَنْ أَبِي نُعَيْمٍ الْقَتْلَ‏.‏ وَقَالَ عُبَيْدُ اللَّهِ إِمَّا أَنْ يُقَادَ أَهْلُ الْقَتِيلِ‏.‏\hadithno{6880}\hadithtrans{Narrated Abu Huraira:In the year of the Conquest of Mecca, the tribe of Khuza`a killed a man from the tribe of Bani Laith in revenge for a killed person belonging to them in the Pre-Islamic Period of Ignorance. So Allah's Apostle got up saying, "Allah held back the (army having) elephants from Mecca, but He let His Apostle and the believers overpower the infidels (of Mecca). Beware! (Mecca is a sanctuary)! Verily! Fighting in Mecca was not permitted for anybody before me, nor will it be permitted for anybody after me; It was permitted for me only for a while (an hour or so) of that day. No doubt! It is at this moment a sanctuary; its thorny shrubs should not be uprooted; its trees should not be cut down; and its Luqata (fallen things) should not be picked up except by the one who would look for its owner. And if somebody is killed, his closest relative has the right to choose one of two things, i.e., either the Blood money or retaliation by having the killer killed." Then a man from Yemen, called Abu Shah, stood up and said, "Write that) for me, O Allah's Messenger (ﷺ)!" Allah's Messenger (ﷺ) said (to his companions), "Write that for Abu Shah." Then another man from Quraish got up, saying, "O Allah's Messenger (ﷺ)! Except Al- Idhkhir (a special kind of grass) as we use it in our houses and for graves." Allah's Messenger (ﷺ) said, "Except Al-idhkkir}}
\hadithdefcmd{bukhari}{6881}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَتْ فِي بَنِي إِسْرَائِيلَ قِصَاصٌ، وَلَمْ تَكُنْ فِيهِمُ الدِّيَةُ فَقَالَ اللَّهُ لِهَذِهِ الأُمَّةِ ‏\{‏كُتِبَ عَلَيْكُمُ الْقِصَاصُ فِي الْقَتْلَى‏\}‏ إِلَى هَذِهِ الآيَةِ ‏\{‏فَمَنْ عُفِيَ لَهُ مِنْ أَخِيهِ شَىْءٌ‏\}‏‏.‏ قَالَ ابْنُ عَبَّاسٍ فَالْعَفْوُ أَنْ يَقْبَلَ الدِّيَةَ فِي الْعَمْدِ، قَالَ ‏\{‏فَاتِّبَاعٌ بِالْمَعْرُوفِ‏\}‏ أَنْ يَطْلُبَ بِمَعْرُوفٍ وَيُؤَدِّيَ بِإِحْسَانٍ‏.‏\hadithno{6881}\hadithtrans{Narrated Ibn `Abbas:For the children of Israel the punishment for crime was Al-Qisas only (i.e., the law of equality in punishment) and the payment of Blood money was not permitted as an alternate. But Allah said to this nation (Muslims): 'O you who believe! Qisas is prescribed for you in case of murder, .....(up to) ...end of the Verse. (2.178) Ibn `Abbas added: Remission (forgiveness) in this Verse, means to accept the Blood-money in an intentional murder. Ibn `Abbas added: The Verse: 'Then the relatives should demand Blood-money in a reasonable manner.' (2.178) means that the demand should be reasonable and it is to be compensated with handsome gratitude}}
\hadithdefcmd{bukhari}{6882}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي حُسَيْنٍ، حَدَّثَنَا نَافِعُ بْنُ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَبْغَضُ النَّاسِ إِلَى اللَّهِ ثَلاَثَةٌ مُلْحِدٌ فِي الْحَرَمِ، وَمُبْتَغٍ فِي الإِسْلاَمِ سُنَّةَ الْجَاهِلِيَّةِ، وَمُطَّلِبُ دَمِ امْرِئٍ بِغَيْرِ حَقٍّ لِيُهَرِيقَ دَمَهُ ‏"‏‏.‏\hadithno{6882}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "The most hated persons to Allah are three: (1) A person who deviates from the right conduct, i.e., an evil doer, in the Haram (sanctuaries of Mecca and Medina); (2) a person who seeks that the traditions of the Pre-Islamic Period of Ignorance, should remain in Islam (3) and a person who seeks to shed somebody's blood without any right}}
\hadithdefcmd{bukhari}{6883}{حَدَّثَنَا فَرْوَةُ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، هُزِمَ الْمُشْرِكُونَ يَوْمَ أُحُدٍ‏.‏ وَحَدَّثَنِي مُحَمَّدُ بْنُ حَرْبٍ، حَدَّثَنَا أَبُو مَرْوَانَ، يَحْيَى بْنُ أَبِي زَكَرِيَّاءَ عَنْ هِشَامٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ صَرَخَ إِبْلِيسُ يَوْمَ أُحُدٍ فِي النَّاسِ يَا عِبَادَ اللَّهِ أُخْرَاكُمْ‏.‏ فَرَجَعَتْ أُولاَهُمْ عَلَى أُخْرَاهُمْ حَتَّى قَتَلُوا الْيَمَانَ فَقَالَ حُذَيْفَةُ أَبِي أَبِي‏.‏ فَقَتَلُوهُ، فَقَالَ حُذَيْفَةُ غَفَرَ اللَّهُ لَكُمْ‏.‏ قَالَ وَقَدْ كَانَ انْهَزَمَ مِنْهُمْ قَوْمٌ حَتَّى لَحِقُوا بِالطَّائِفِ‏.‏\hadithno{6883}\hadithtrans{Narrated `Aisha:The pagans were defeated on the day (of the battle) of Uhud. Satan shouted among the people on the day of Uhud, "O Allah's worshippers! Beware of what is behind you!" So the front file of the army attacked the back files (mistaking them for the enemy) till they killed Al-Yaman. Hudhaifa (bin Al- Yaman) shouted, "My father!" My father! But they killed him. Hudhaifa said, "May Allah forgive you." (The narrator added: Some of the defeated pagans fled till they reached Taif)}}
\hadithdefcmd{bukhari}{6884}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا حَبَّانُ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، أَنَّ يَهُودِيًّا، رَضَّ رَأْسَ جَارِيَةٍ بَيْنَ حَجَرَيْنِ، فَقِيلَ لَهَا مَنْ فَعَلَ بِكِ هَذَا أَفُلاَنٌ أَفُلاَنٌ حَتَّى سُمِّيَ الْيَهُودِيُّ فَأَوْمَأَتْ بِرَأْسِهَا، فَجِيءَ بِالْيَهُودِيِّ فَاعْتَرَفَ، فَأَمَرَ بِهِ النَّبِيُّ صلى الله عليه وسلم فَرُضَّ رَأْسُهُ بِالْحِجَارَةِ‏.‏ وَقَدْ قَالَ هَمَّامٌ بِحَجَرَيْنِ‏.‏\hadithno{6884}\hadithtrans{Narrated Anas bin Malik:A Jew crushed the head of a girl between two stones. It was said to her. "Who has done this to you, such-and-such person, such-and-such person?" When the name of the Jew was mentioned, she nodded with her head, agreeing. So the Jew was brought and he confessed. The Prophet (ﷺ) ordered that his head be crushed with the stones. (Hammam said, "with two stones)}}
\hadithdefcmd{bukhari}{6885}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَتَلَ يَهُودِيًّا بِجَارِيَةٍ قَتَلَهَا عَلَى أَوْضَاحٍ لَهَا‏.‏\hadithno{6885}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) killed a Jew for killing a girl in order to take her ornaments}}
\hadithdefcmd{bukhari}{6886}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا مُوسَى بْنُ أَبِي عَائِشَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ لَدَدْنَا النَّبِيَّ صلى الله عليه وسلم فِي مَرَضِهِ فَقَالَ ‏"‏ لاَ تَلُدُّونِي ‏"‏‏.‏ فَقُلْنَا كَرَاهِيَةُ الْمَرِيضِ لِلدَّوَاءِ‏.‏ فَلَمَّا أَفَاقَ قَالَ ‏"‏ لاَ يَبْقَى أَحَدٌ مِنْكُمْ إِلاَّ لُدَّ، غَيْرَ الْعَبَّاسِ فَإِنَّهُ لَمْ يَشْهَدْكُمْ ‏"‏‏.‏\hadithno{6886}\hadithtrans{Narrated `Aisha:We poured medicine into the mouth of the Prophet (ﷺ) during his ailment. He said, "Don't pour medicine into my mouth." (We thought he said that) out of the aversion a patient usually has for medicines. When he improved and felt better he said, "There is none of you but will be forced to drink medicine, except Al-`Abbas, for he did not witness your deed}}
\hadithdefcmd{bukhari}{6888}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، أَنَّ الأَعْرَجَ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ إِنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ نَحْنُ الآخِرُونَ السَّابِقُونَ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ وَبِإِسْنَادِهِ ‏"‏ لَوِ اطَّلَعَ فِي بَيْتِكَ أَحَدٌ وَلَمْ تَأْذَنْ لَهُ، خَذَفْتَهُ بِحَصَاةٍ فَفَقَأْتَ عَيْنَهُ، مَا كَانَ عَلَيْكَ مِنْ جُنَاحٍ ‏"‏‏.‏\hadithno{6888}\hadithtrans{Narrated Abu Huraira:That he heard Allah's Messenger (ﷺ) saying, "We (Muslims) are the last (to come) but (will be) the foremost (on the Day of Resurrection)." And added, "If someone is peeping (looking secretly) into your house without your permission, and you throw a stone at him and destroy his eyes, there will be no blame on you}}
\hadithdefcmd{bukhari}{6889}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ حُمَيْدٍ،، أَنَّ رَجُلاً، اطَّلَعَ فِي بَيْتِ النَّبِيِّ صلى الله عليه وسلم فَسَدَّدَ إِلَيْهِ مِشْقَصًا‏.‏ فَقُلْتُ مَنْ حَدَّثَكَ قَالَ أَنَسُ بْنُ مَالِكٍ‏.‏\hadithno{6889}\hadithtrans{Narrated Yahya:Humaid said, "A man peeped into the house of the Prophet (ﷺ) and the Prophet (ﷺ) aimed an arrow head at him to hit him." I asked, "Who told you that?" He said, "Anas bin Malik" (See Hadith No. 258 and 259, Vol)}}
\hadithdefcmd{bukhari}{6890}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا أَبُو أُسَامَةَ، قَالَ هِشَامٌ أَخْبَرَنَا عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا كَانَ يَوْمَ أُحُدٍ هُزِمَ الْمُشْرِكُونَ فَصَاحَ إِبْلِيسُ أَىْ عِبَادَ اللَّهِ أُخْرَاكُمْ‏.‏ فَرَجَعَتْ أُولاَهُمْ، فَاجْتَلَدَتْ هِيَ وَأُخْرَاهُمْ، فَنَظَرَ حُذَيْفَةُ فَإِذَا هُوَ بِأَبِيهِ الْيَمَانِ فَقَالَ أَىْ عِبَادَ اللَّهِ أَبِي أَبِي‏.‏ قَالَتْ فَوَاللَّهِ مَا احْتَجَزُوا حَتَّى قَتَلُوهُ‏.‏ قَالَ حُذَيْفَةُ غَفَرَ اللَّهُ لَكُمْ‏.‏ قَالَ عُرْوَةُ فَمَا زَالَتْ فِي حُذَيْفَةَ مِنْهُ بَقِيَّةٌ حَتَّى لَحِقَ بِاللَّهِ‏.‏\hadithno{6890}\hadithtrans{Narrated `Aisha:"When it was the day of (the battle of) Uhud, the pagans were defeated. Then Satan shouted, "O Allah's worshipers! Beware of what is behind you!" So the front files attacked the back files of the army. Hudhaifa looked, and behold, there was his father, Al-Yaman (being attacked) ! He shouted (to his companions), "O Allah's worshipers, my father, my father!" But by Allah, they did not stop till they killed him (i.e., Hudhaifa's father). Hudhaifa said, "May Allah forgive you." (`Urwa said, Hudhaifa continued asking Allah's Forgiveness for the killer of his father till he died)}}
\hadithdefcmd{bukhari}{6891}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا يَزِيدُ بْنُ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ، قَالَ خَرَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم إِلَى خَيْبَرَ فَقَالَ رَجُلٌ مِنْهُمْ أَسْمِعْنَا يَا عَامِرُ مِنْ هُنَيْهَاتِكَ‏.‏ فَحَدَا بِهِمْ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنِ السَّائِقُ ‏"‏ قَالُوا عَامِرٌ‏.‏ فَقَالَ ‏"‏ رَحِمَهُ اللَّهُ ‏"‏‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ هَلاَّ أَمْتَعْتَنَا بِهِ‏.‏ فَأُصِيبَ صَبِيحَةَ لَيْلَتِهِ فَقَالَ الْقَوْمُ حَبِطَ عَمَلُهُ، قَتَلَ نَفْسَهُ‏.‏ فَلَمَّا رَجَعْتُ وَهُمْ يَتَحَدَّثُونَ أَنَّ عَامِرًا حَبِطَ عَمَلُهُ، فَجِئْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقُلْتُ يَا نَبِيَّ اللَّهِ فَدَاكَ أَبِي وَأُمِّي، زَعَمُوا أَنَّ عَامِرًا حَبِطَ عَمَلُهُ‏.‏ فَقَالَ ‏"‏ كَذَبَ مَنْ قَالَهَا، إِنَّ لَهُ لأَجْرَيْنِ اثْنَيْنِ، إِنَّهُ لَجَاهِدٌ مُجَاهِدٌ، وَأَىُّ قَتْلٍ يَزِيدُهُ عَلَيْهِ ‏"‏‏.‏\hadithno{6891}\hadithtrans{Narrated Salama:We went out with the Prophet (ﷺ) to Khaibar. A man (from the companions) said, "O 'Amir! Let us hear some of your Huda (camel-driving songs.)" So he sang some of them (i.e. a lyric in harmony with the camels walk). The Prophet (ﷺ) said, "Who is the driver (of these camels)?" They said, "Amir." The Prophet said, "May Allah bestow His Mercy on him !" The people said, "O Allah's Messenger (ﷺ)! Would that you let us enjoy his company longer!" Then 'Amir was killed the following morning. The people said, "The good deeds of 'Amir are lost as he has killed himself." I returned at the time while they were talking about that. I went to the Prophet (ﷺ) and said, "O Allah's Prophet! Let my father be sacrificed for you! The people claim that 'Amir's good deeds are lost." The Prophet (ﷺ) said, "Whoever says so is a liar, for 'Amir will have a double reward as he exerted himself to obey Allah and fought in Allah's Cause. No other way of killing would have granted him greater reward}}
\hadithdefcmd{bukhari}{6892}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا قَتَادَةُ، قَالَ سَمِعْتُ زُرَارَةَ بْنَ أَوْفَى، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَجُلاً، عَضَّ يَدَ رَجُلٍ، فَنَزَعَ يَدَهُ مِنْ فَمِهِ، فَوَقَعَتْ ثَنِيَّتَاهُ، فَاخْتَصَمُوا إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ يَعَضُّ أَحَدُكُمْ أَخَاهُ كَمَا يَعَضُّ الْفَحْلُ، لاَ دِيَةَ لَكَ ‏"‏‏.‏\hadithno{6892}\hadithtrans{Narrated `Imran bin Husain:A man bit another man's hand and the latter pulled his hand out of his mouth by force, causing two of his incisors (teeth) to fall out. They submitted their case to the Prophet, who said, "One of you bit his brother as a male camel bites. (Go away), there is no Diya (Blood-money) for you}}
\hadithdefcmd{bukhari}{6893}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ صَفْوَانَ بْنِ يَعْلَى، عَنْ أَبِيهِ، قَالَ خَرَجْتُ فِي غَزْوَةٍ، فَعَضَّ رَجُلٌ فَانْتَزَعَ ثَنِيَّتَهُ، فَأَبْطَلَهَا النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{6893}\hadithtrans{Narrated Ya`la:I went out in one of the Ghazwa and a man bit another man and as a result, an incisor tooth of the former was pulled out. The Prophet (ﷺ) cancelled the case}}
\hadithdefcmd{bukhari}{6894}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ ابْنَةَ النَّضْرِ، لَطَمَتْ جَارِيَةً، فَكَسَرَتْ ثَنِيَّتَهَا، فَأَتَوُا النَّبِيَّ صلى الله عليه وسلم فَأَمَرَ بِالْقِصَاصِ‏.‏\hadithno{6894}\hadithtrans{Narrated Anas:The daughter of An-Nadr slapped a girl and broke her incisor tooth. They (the relatives of that girl), came to the Prophet (ﷺ) and he gave the order of Qisas (equality in punishment)}}
\hadithdefcmd{bukhari}{6895}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ هَذِهِ وَهَذِهِ سَوَاءٌ ‏"‏، يَعْنِي الْخِنْصَرَ وَالإِبْهَامَ‏.‏\hadithno{6895}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "This and this are the same." He meant the little finger and the thumb}}
\hadithdefcmd{bukhari}{6895p2}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم نَحْوَهُ‏.‏\hadithno{6895.2}\hadithtrans{Narrated Ibn `Abbas:I heard the Prophet (saying the same as above Hadith)}}
\hadithdefcmd{bukhari}{6896}{وَقَالَ لِي ابْنُ بَشَّارٍ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ غُلاَمًا، قُتِلَ غِيلَةً فَقَالَ عُمَرُ لَوِ اشْتَرَكَ فِيهَا أَهْلُ صَنْعَاءَ لَقَتَلْتُهُمْ‏.‏ وَقَالَ مُغِيرَةُ بْنُ حَكِيمٍ عَنْ أَبِيهِ إِنَّ أَرْبَعَةً قَتَلُوا صَبِيًّا فَقَالَ عُمَرُ مِثْلَهُ‏.‏ وَأَقَادَ أَبُو بَكْرٍ وَابْنُ الزُّبَيْرِ وَعَلِيٌّ وَسُوَيْدُ بْنُ مُقَرِّنٍ مِنْ لَطْمَةٍ‏.‏ وَأَقَادَ عُمَرُ مِنْ ضَرْبَةٍ بِالدِّرَّةِ‏.‏ وَأَقَادَ عَلِيٌّ مِنْ ثَلاَثَةِ أَسْوَاطٍ‏.‏ وَاقْتَصَّ شُرَيْحٌ مِنْ سَوْطٍ وَخُمُوشٍ‏.‏\hadithno{6896}\hadithtrans{Ibn 'Umar said:A boy was assassinated. 'Umar said, "If all the people of San'a took part in the assassination I would kill them all." Al-Mughira bin Hakim said that his father said, "Four persons killed a boy, and 'Umar said (as above)." Abu Bakr, Ibn Az-Zubair, 'Ali and Suwaid bin Muqarrin gave the judgement of Al-Qisas (equality in punishment) in cases of slapping. And 'Umar carried out Al-Qisas for a strike with a stick. And 'Ali carried out Al-Qisas for three lashes with a whip. And Shuraih carried out for one last and for scratching}}
\hadithdefcmd{bukhari}{6897}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنَا مُوسَى بْنُ أَبِي عَائِشَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَتْ عَائِشَةُ لَدَدْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فِي مَرَضِهِ، وَجَعَلَ يُشِيرُ إِلَيْنَا ‏"‏ لاَ تَلُدُّونِي ‏"‏‏.‏ قَالَ فَقُلْنَا كَرَاهِيَةُ الْمَرِيضِ بِالدَّوَاءِ، فَلَمَّا أَفَاقَ قَالَ ‏"‏ أَلَمْ أَنْهَكُمْ أَنْ تَلُدُّونِي ‏"‏‏.‏ قَالَ قُلْنَا كَرَاهِيَةٌ لِلدَّوَاءِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَبْقَى مِنْكُمْ أَحَدٌ إِلاَّ لُدَّ ـ وَأَنَا أَنْظُرُ ـ إِلاَّ الْعَبَّاسَ فَإِنَّهُ لَمْ يَشْهَدْكُمْ ‏"‏‏.‏\hadithno{6897}\hadithtrans{Narrated `Aisha:We poured medicine into the mouth of Allah's Messenger (ﷺ) during his illness, and he pointed out to us intending to say, "Don't pour medicine into my mouth." We thought that his refusal was out of the aversion a patient usually has for medicine. When he improved and felt a bit better he said (to us.) "Didn't I forbid you to pour medicine into my mouth?" We said, "We thought (you did so) because of the aversion, one usually have for medicine." Allah's Messenger (ﷺ) said, "There is none of you but will be forced to drink medicine, and I will watch you, except Al-`Abbas, for he did not witness this act of yours}}
\hadithdefcmd{bukhari}{6898}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سَعِيدُ بْنُ عُبَيْدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، زَعَمَ أَنَّ رَجُلاً، مِنَ الأَنْصَارِ يُقَالُ لَهُ سَهْلُ بْنُ أَبِي حَثْمَةَ أَخْبَرَهُ أَنَّ نَفَرًا مِنْ قَوْمِهِ انْطَلَقُوا إِلَى خَيْبَرَ فَتَفَرَّقُوا فِيهَا، وَوَجَدُوا أَحَدَهُمْ قَتِيلاً، وَقَالُوا لِلَّذِي وُجِدَ فِيهِمْ قَتَلْتُمْ صَاحِبَنَا‏.‏ قَالُوا مَا قَتَلْنَا وَلاَ عَلِمْنَا قَاتِلاً‏.‏ فَانْطَلَقُوا إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالُوا يَا رَسُولَ اللَّهِ انْطَلَقْنَا إِلَى خَيْبَرَ فَوَجَدْنَا أَحَدَنَا قَتِيلاً‏.‏ فَقَالَ ‏"‏ الْكُبْرَ الْكُبْرَ ‏"‏‏.‏ فَقَالَ لَهُمْ ‏"‏ تَأْتُونَ بِالْبَيِّنَةِ عَلَى مَنْ قَتَلَهُ ‏"‏‏.‏ قَالُوا مَا لَنَا بَيِّنَةٌ‏.‏ قَالَ ‏"‏ فَيَحْلِفُونَ ‏"‏‏.‏ قَالُوا لاَ نَرْضَى بِأَيْمَانِ الْيَهُودِ‏.‏ فَكَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُبْطِلَ دَمَهُ، فَوَدَاهُ مِائَةً مِنْ إِبِلِ الصَّدَقَةِ‏.‏\hadithno{6898}\hadithtrans{Narrated Sahl bin Abi Hathma:(a man from the Ansar) that a number of people from his tribe went to Khaibar and dispersed, and then they found one of them murdered. They said to the people with whom the corpse had been found, "You have killed our companion!" Those people said, "Neither have we killed him, nor do we know his killer." The bereaved group went to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! We went to Khaibar and found one of us murdered." The Prophet (ﷺ) said, "Let the older among you come forward and speak." Then the Prophet (ﷺ) said, to them, "Bring your proof against the killer." They said "We have no proof." The Prophet (ﷺ) said, "Then they (the defendants) will take an oath." They said, "We do not accept the oaths of the Jews." Allah's Messenger (ﷺ) did not like that the Blood-money of the killed one be lost without compensation, so he paid one-hundred camels out of the camels of Zakat (to the relatives of the deceased) as Diya (Blood-money)}}
\hadithdefcmd{bukhari}{6899}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو بِشْرٍ، إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ الأَسَدِيُّ حَدَّثَنَا الْحَجَّاجُ بْنُ أَبِي عُثْمَانَ، حَدَّثَنِي أَبُو رَجَاءٍ، مِنْ آلِ أَبِي قِلاَبَةَ حَدَّثَنِي أَبُو قِلاَبَةَ، أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، أَبْرَزَ سَرِيرَهُ يَوْمًا لِلنَّاسِ، ثُمَّ أَذِنَ لَهُمْ فَدَخَلُوا فَقَالَ مَا تَقُولُونَ فِي الْقَسَامَةِ قَالَ نَقُولُ الْقَسَامَةُ الْقَوَدُ بِهَا حَقٌّ، وَقَدْ أَقَادَتْ بِهَا الْخُلَفَاءُ‏.‏ قَالَ لِي مَا تَقُولُ يَا أَبَا قِلاَبَةَ وَنَصَبَنِي لِلنَّاسِ‏.‏ فَقُلْتُ يَا أَمِيرَ الْمُؤْمِنِينَ عِنْدَكَ رُءُوسُ الأَجْنَادِ وَأَشْرَافُ الْعَرَبِ، أَرَأَيْتَ لَوْ أَنَّ خَمْسِينَ مِنْهُمْ شَهِدُوا عَلَى رَجُلٍ مُحْصَنٍ بِدِمَشْقَ أَنَّهُ قَدْ زَنَى، لَمْ يَرَوْهُ أَكُنْتَ تَرْجُمُهُ قَالَ لاَ‏.‏ قُلْتُ أَرَأَيْتَ لَوْ أَنَّ خَمْسِينَ مِنْهُمْ شَهِدُوا عَلَى رَجُلٍ بِحِمْصَ أَنَّهُ سَرَقَ أَكُنْتَ تَقْطَعُهُ وَلَمْ يَرَوْهُ قَالَ لاَ‏.‏ قُلْتُ فَوَاللَّهِ مَا قَتَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَطُّ، إِلاَّ فِي إِحْدَى ثَلاَثِ خِصَالٍ رَجُلٌ قَتَلَ بِجَرِيرَةِ نَفْسِهِ فَقُتِلَ، أَوْ رَجُلٌ زَنَى بَعْدَ إِحْصَانٍ، أَوْ رَجُلٌ حَارَبَ اللَّهَ وَرَسُولَهُ وَارْتَدَّ عَنِ الإِسْلاَمِ‏.‏ فَقَالَ الْقَوْمُ أَوَلَيْسَ قَدْ حَدَّثَ أَنَسُ بْنُ مَالِكٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَطَعَ فِي السَّرَقِ وَسَمَرَ الأَعْيُنَ، ثُمَّ نَبَذَهُمْ فِي الشَّمْسِ‏.‏ فَقُلْتُ أَنَا أُحَدِّثُكُمْ حَدِيثَ أَنَسٍ، حَدَّثَنِي أَنَسٌ أَنَّ نَفَرًا مِنْ عُكْلٍ ثَمَانِيَةً قَدِمُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَايَعُوهُ عَلَى الإِسْلاَمِ، فَاسْتَوْخَمُوا الأَرْضَ فَسَقِمَتْ أَجْسَامُهُمْ، فَشَكَوْا ذَلِكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَفَلاَ تَخْرُجُونَ مَعَ رَاعِينَا فِي إِبِلِهِ، فَتُصِيبُونَ مِنْ أَلْبَانِهَا وَأَبْوَالِهَا ‏"‏‏.‏ قَالُوا بَلَى، فَخَرَجُوا فَشَرِبُوا مِنْ أَلْبَانِهَا وَأَبْوَالِهَا فَصَحُّوا، فَقَتَلُوا رَاعِيَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَطْرَدُوا النَّعَمَ، فَبَلَغَ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَرْسَلَ فِي آثَارِهِمْ، فَأُدْرِكُوا فَجِيءَ بِهِمْ، فَأَمَرَ بِهِمْ فَقُطِّعَتْ أَيْدِيهِمْ وَأَرْجُلُهُمْ، وَسَمَرَ أَعْيُنَهُمْ، ثُمَّ نَبَذَهُمْ فِي الشَّمْسِ حَتَّى مَاتُوا‏.‏ قُلْتُ وَأَىُّ شَىْءٍ أَشَدُّ مِمَّا صَنَعَ هَؤُلاَءِ ارْتَدُّوا عَنِ الإِسْلاَمِ وَقَتَلُوا وَسَرَقُوا‏.‏ فَقَالَ عَنْبَسَةُ بْنُ سَعِيدٍ وَاللَّهِ إِنْ سَمِعْتُ كَالْيَوْمِ قَطُّ‏.‏ فَقُلْتُ أَتَرُدُّ عَلَىَّ حَدِيثِي يَا عَنْبَسَةُ قَالَ لاَ، وَلَكِنْ جِئْتَ بِالْحَدِيثِ عَلَى وَجْهِهِ، وَاللَّهِ لاَ يَزَالُ هَذَا الْجُنْدُ بِخَيْرٍ مَا عَاشَ هَذَا الشَّيْخُ بَيْنَ أَظْهُرِهِمْ‏.‏ قُلْتُ وَقَدْ كَانَ فِي هَذَا سُنَّةٌ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم دَخَلَ عَلَيْهِ نَفَرٌ مِنَ الأَنْصَارِ فَتَحَدَّثُوا عِنْدَهُ، فَخَرَجَ رَجُلٌ مِنْهُمْ بَيْنَ أَيْدِيهِمْ فَقُتِلَ، فَخَرَجُوا بَعْدَهُ، فَإِذَا هُمْ بِصَاحِبِهِمْ يَتَشَحَّطُ فِي الدَّمِ، فَرَجَعُوا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا يَا رَسُولَ اللَّهِ صَاحِبُنَا كَانَ تَحَدَّثَ مَعَنَا، فَخَرَجَ بَيْنَ أَيْدِينَا، فَإِذَا نَحْنُ بِهِ يَتَشَحَّطُ فِي الدَّمِ‏.‏ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ بِمَنْ تَظُنُّونَ أَوْ تَرَوْنَ قَتَلَهُ ‏"‏‏.‏ قَالُوا نَرَى أَنَّ الْيَهُودَ قَتَلَتْهُ‏.‏ فَأَرْسَلَ إِلَى الْيَهُودِ فَدَعَاهُمْ‏.‏ فَقَالَ ‏"‏ آنْتُمْ قَتَلْتُمْ هَذَا ‏"‏‏.‏ قَالُوا لاَ‏.‏ قَالَ ‏"‏ أَتَرْضَوْنَ نَفَلَ خَمْسِينَ مِنَ الْيَهُودِ مَا قَتَلُوهُ ‏"‏‏.‏ فَقَالُوا مَا يُبَالُونَ أَنْ يَقْتُلُونَا أَجْمَعِينَ ثُمَّ يَنْتَفِلُونَ‏.‏ قَالَ ‏"‏ أَفَتَسْتَحِقُّونَ الدِّيَةَ بِأَيْمَانِ خَمْسِينَ مِنْكُمْ ‏"‏‏.‏ قَالُوا مَا كُنَّا لِنَحْلِفَ، فَوَدَاهُ مِنْ عِنْدِهِ‏.‏ قُلْتُ وَقَدْ كَانَتْ هُذَيْلٌ خَلَعُوا خَلِيعًا لَهُمْ فِي الْجَاهِلِيَّةِ فَطَرَقَ أَهْلَ بَيْتٍ مِنَ الْيَمَنِ بِالْبَطْحَاءِ فَانْتَبَهَ لَهُ رَجُلٌ مِنْهُمْ فَحَذَفَهُ بِالسَّيْفِ فَقَتَلَهُ، فَجَاءَتْ هُذَيْلٌ فَأَخَذُوا الْيَمَانِيَ فَرَفَعُوهُ إِلَى عُمَرَ بِالْمَوْسِمِ وَقَالُوا قَتَلَ صَاحِبَنَا‏.‏ فَقَالَ إِنَّهُمْ قَدْ خَلَعُوهُ‏.‏ فَقَالَ يُقْسِمُ خَمْسُونَ مِنْ هُذَيْلٍ مَا خَلَعُوهُ‏.‏ قَالَ فَأَقْسَمَ مِنْهُمْ تِسْعَةٌ وَأَرْبَعُونَ رَجُلاً، وَقَدِمَ رَجُلٌ مِنْهُمْ مِنَ الشَّأْمِ فَسَأَلُوهُ أَنْ يُقْسِمَ فَافْتَدَى يَمِينَهُ مِنْهُمْ بِأَلْفِ دِرْهَمٍ، فَأَدْخَلُوا مَكَانَهُ رَجُلاً آخَرَ، فَدَفَعَهُ إِلَى أَخِي الْمَقْتُولِ فَقُرِنَتْ يَدُهُ بِيَدِهِ، قَالُوا فَانْطَلَقَا وَالْخَمْسُونَ الَّذِينَ أَقْسَمُوا حَتَّى إِذَا كَانُوا بِنَخْلَةَ، أَخَذَتْهُمُ السَّمَاءُ فَدَخَلُوا فِي غَارٍ فِي الْجَبَلِ، فَانْهَجَمَ الْغَارُ عَلَى الْخَمْسِينَ الَّذِينَ أَقْسَمُوا فَمَاتُوا جَمِيعًا، وَأَفْلَتَ الْقَرِينَانِ وَاتَّبَعَهُمَا حَجَرٌ فَكَسَرَ رِجْلَ أَخِي الْمَقْتُولِ، فَعَاشَ حَوْلاً ثُمَّ مَاتَ‏.‏ قُلْتُ وَقَدْ كَانَ عَبْدُ الْمَلِكِ بْنُ مَرْوَانَ أَقَادَ رَجُلاً بِالْقَسَامَةِ ثُمَّ نَدِمَ بَعْدَ مَا صَنَعَ، فَأَمَرَ بِالْخَمْسِينَ الَّذِينَ أَقْسَمُوا فَمُحُوا مِنَ الدِّيوَانِ وَسَيَّرَهُمْ إِلَى الشَّأْمِ‏.‏\hadithno{6899}\hadithtrans{Narrated Abu Qilaba:Once `Umar bin `Abdul `Aziz sat on his throne in the courtyard of his house so that the people might gather before him. Then he admitted them and (when they came in), he said, "What do you think of Al-Qasama?" They said, "We say that it is lawful to depend on Al-Qasama in Qisas, as the previous Muslim Caliphs carried out Qisas depending on it." Then he said to me, "O Abu Qilaba! What do you say about it?" He let me appear before the people and I said, "O Chief of the Believers! You have the chiefs of the army staff and the nobles of the Arabs. If fifty of them testified that a married man had committed illegal sexual intercourse in Damascus but they had not seen him (doing so), would you stone him?" He said, "No." I said, "If fifty of them testified that a man had committed theft in Hums, would you cut off his hand though they did not see him?" He replied, "No." I said, "By Allah, Allah's Messenger (ﷺ) never killed anyone except in one of the following three situations: (1) A person who killed somebody unjustly, was killed (in Qisas,) (2) a married person who committed illegal sexual intercourse and (3) a man who fought against Allah and His Apostle and deserted Islam and became an apostate." Then the people said, "Didn't Anas bin Malik narrate that Allah's Messenger (ﷺ) cut off the hands of the thieves, branded their eyes and then, threw them in the sun?" I said, "I shall tell you the narration of Anas. Anas said: "Eight persons from the tribe of `Ukl came to Allah's Messenger (ﷺ) and gave the Pledge of allegiance for Islam (became Muslim). The climate of the place (Medina) did not suit them, so they became sick and complained about that to Allah's Messenger (ﷺ). He said (to them ), "Won't you go out with the shepherd of our camels and drink of the camels' milk and urine (as medicine)?" They said, "Yes." So they went out and drank the camels' milk and urine, and after they became healthy, they killed the shepherd of Allah's Messenger (ﷺ) and took away all the camels. This news reached Allah's Messenger (ﷺ) , so he sent (men) to follow their traces and they were captured and brought (to the Prophet). He then ordered to cut their hands and feet, and their eyes were branded with heated pieces of iron, and then he threw them in the sun till they died." I said, "What can be worse than what those people did? They deserted Islam, committed murder and theft." Then 'Anbasa bin Sa`id said, "By Allah, I never heard a narration like this of today." I said, "O 'Anbasa! You deny my narration?" 'Anbasa said, "No, but you have related the narration in the way it should be related. By Allah, these people are in welfare as long as this Sheikh (Abu Qilaba) is among them." I added, "Indeed in this event there has been a tradition set by Allah's Messenger (ﷺ). The narrator added: Some Ansari people came to the Prophet (ﷺ) and discussed some matters with him, a man from amongst them went out and was murdered. Those people went out after him, and behold, their companion was swimming in blood. They returned to Allah's Messenger (ﷺ) and said to him, "O Allah's Apostle, we have found our companion who had talked with us and gone out before us, swimming in blood (killed)." Allah's Messenger (ﷺ) went out and asked them, "Whom do you suspect or whom do you think has killed him?" They said, "We think that the Jews have killed him." The Prophet (ﷺ) sent for the Jews and asked them, "Did you kill this (person)?" They replied, "No." He asked the Al-Ansars, "Do you agree that I let fifty Jews take an oath that they have not killed him?" They said, "It matters little for the Jews to kill us all and then take false oaths." He said, "Then would you like to receive the Diya after fifty of you have taken an oath (that the Jews have killed your man)?" They said, "We will not take the oath." Then the Prophet (ﷺ) himself paid them the Diya (Blood-money)." The narrator added, "The tribe of Hudhail repudiated one of their men (for his evil conduct) in the Pre-Islamic period of Ignorance. Then, at a place called Al-Batha' (near Mecca), the man attacked a Yemenite family at night to steal from them, but a. man from the family noticed him and struck him with his sword and killed him. The tribe of Hudhail came and captured the Yemenite and brought him to `Umar during the Hajj season and said, "He has killed our companion." The Yemenite said, "But these people had repudiated him (i.e., their companion)." `Umar said, "Let fifty persons of Hudhail swear that they had not repudiated him." So forty-nine of them took the oath and then a person belonging to them, came from Sham and they requested him to swear similarly, but he paid one-thousand Dirhams instead of taking the oath. They called another man instead of him and the new man shook hands with the brother of the deceased. Some people said, "We and those fifty men who had taken false oaths (Al-Qasama) set out, and when they reached a place called Nakhlah, it started raining so they entered a cave in the mountain, and the cave collapsed on those fifty men who took the false oath, and all of them died except the two persons who had shaken hands with each other. They escaped death but a stone fell on the leg of the brother of the deceased and broke it, whereupon he survived for one year and then died." I further said, "`Abdul Malik bin Marwan sentenced a man to death in Qisas (equality in punishment) for murder, basing his judgment on Al-Qasama, but later on he regretted that judgment and ordered that the names of the fifty persons who had taken the oath (Al-Qasama), be erased from the register, and he exiled them in Sham}}
\hadithdefcmd{bukhari}{6900}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ أَنَسٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ رَجُلاً، اطَّلَعَ فِي بَعْضِ حُجَرِ النَّبِيِّ صلى الله عليه وسلم فَقَامَ إِلَيْهِ بِمِشْقَصٍ أَوْ بِمَشَاقِصَ وَجَعَلَ يَخْتِلُهُ لِيَطْعُنَهُ‏.‏\hadithno{6900}\hadithtrans{Narrated Anas: A man peeped into one of the dwelling places of the Prophet. The Prophet got up and aimed a sharp-edged arrow head (or wooden stick) at him to poke him stealthily}}
\hadithdefcmd{bukhari}{6901}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَهْلَ بْنَ سَعْدٍ السَّاعِدِيَّ، أَخْبَرَهُ أَنَّ رَجُلاً اطَّلَعَ فِي جُحْرٍ فِي باب رَسُولِ اللَّهِ صلى الله عليه وسلم وَمَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِدْرًى يَحُكُّ بِهِ رَأْسَهُ، فَلَمَّا رَآهُ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لَوْ أَعْلَمُ أَنْ تَنْتَظِرَنِي لَطَعَنْتُ بِهِ فِي عَيْنَيْكَ ‏"‏‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا جُعِلَ الإِذْنُ مِنْ قِبَلِ الْبَصَرِ ‏"‏‏.‏\hadithno{6901}\hadithtrans{Narrated Sahl bin Sa'd As-Sa'idi: A man peeped through a hole in the door of Allah's Messenger's (ﷺ) house, and at that time, Allah's Messenger (ﷺ) had a Midri (an iron comb or bar) with which he was rubbing his head. So when Allah's Messenger (ﷺ) saw him, he said (to him), "If I had been sure that you were looking at me (through the door), I would have poked your eye with this (sharp iron bar)." Allah's Messenger (ﷺ) added, "The asking for permission to enter has been enjoined so that one may not look unlawfully (at what there is in the house without the permission of its people)}}
\hadithdefcmd{bukhari}{6902}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏ "‏ لَوْ أَنَّ امْرَأً اطَّلَعَ عَلَيْكَ بِغَيْرِ إِذْنٍ، فَخَذَفْتَهُ بِعَصَاةٍ، فَفَقَأْتَ عَيْنَهُ، لَمْ يَكُنْ عَلَيْكَ جُنَاحٌ ‏"‏‏.‏\hadithno{6902}\hadithtrans{Narrated Abu Huraira:Abul Qasim said, "If any person peeps at you without your permission and you poke him with a stick and injure his eye, you will not be blamed}}
\hadithdefcmd{bukhari}{6903}{حَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، حَدَّثَنَا مُطَرِّفٌ، قَالَ سَمِعْتُ الشَّعْبِيَّ، قَالَ سَمِعْتُ أَبَا جُحَيْفَةَ، قَالَ سَأَلْتُ عَلِيًّا ـ رضى الله عنه ـ هَلْ عِنْدَكُمْ شَىْءٌ مَا لَيْسَ فِي الْقُرْآنِ وَقَالَ مَرَّةً مَا لَيْسَ عِنْدَ النَّاسِ فَقَالَ وَالَّذِي فَلَقَ الْحَبَّ وَبَرَأَ النَّسَمَةَ مَا عِنْدَنَا إِلاَّ مَا فِي الْقُرْآنِ، إِلاَّ فَهْمًا يُعْطَى رَجُلٌ فِي كِتَابِهِ، وَمَا فِي الصَّحِيفَةِ‏.‏ قُلْتُ وَمَا فِي الصَّحِيفَةِ قَالَ الْعَقْلُ، وَفِكَاكُ الأَسِيرِ، وَأَنْ لاَ يُقْتَلَ مُسْلِمٌ بِكَافِرٍ‏.‏\hadithno{6903}\hadithtrans{Narrated Ash-Shu`bi:I heard Abu Juhaifa saying, "I asked `Ali 'Have you got any Divine literature apart from the Qur'an?' (Once he said...apart from what the people have?) `Ali replied, 'By Him Who made the grain split (germinate) and created the soul, we have nothing except what is in the Qur'an and the ability (gift) of understanding Allah's Book which He may endow a man with and we have what is written in this paper.' I asked, 'What is written in this paper?' He replied, 'Al-`Aql (the regulation of Diya), about the ransom of captives, and the Judgment that a Muslim should not be killed in Qisas (equality in punishment) for killing a disbeliever." (See Hadith No. 283,Vol)}}
\hadithdefcmd{bukhari}{6904}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، وَحَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ امْرَأَتَيْنِ، مِنْ هُذَيْلٍ رَمَتْ إِحْدَاهُمَا الأُخْرَى، فَطَرَحَتْ جَنِينَهَا، فَقَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِيهَا بِغُرَّةٍ عَبْدٍ أَوْ أَمَةٍ‏.‏\hadithno{6904}\hadithtrans{Narrated Abu Huraira:Two women from the tribe of Hudhail (fought with each other) and one of them threw (a stone at) the other, causing her to have a miscarriage and Allah's Messenger (ﷺ) gave his verdict that the killer (of the fetus) should give a male or female slave (as a Diya)}}
\hadithdefcmd{bukhari}{6906}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنْ عُمَرَ ـ رضى الله عنه ـ أَنَّهُ اسْتَشَارَهُمْ فِي إِمْلاَصِ الْمَرْأَةِ فَقَالَ الْمُغِيرَةُ قَضَى النَّبِيُّ صلى الله عليه وسلم بِالْغُرَّةِ عَبْدٍ أَوْ أَمَةٍ‏.‏ فَقَالَ ائْتِ مَنْ يَشْهَدُ مَعَكَ، فَشَهِدَ مُحَمَّدُ بْنُ مَسْلَمَةَ أَنَّهُ شَهِدَ النَّبِيَّ صلى الله عليه وسلم قَضَى بِهِ‏.‏\hadithno{6906}\hadithtrans{Narrated Hisham's father from Al-Mughira bin Shu'ba: 'Umar consulted the companions about the case of a woman's abortion (caused by somebody else). Al-Mughira said: The Prophet (ﷺ) gave the verdict that a male or female slave should be given (as a Diya). Then Muhammad bin Maslama testified that he had witnessed the Prophet (ﷺ) giving such a verdict}}
\hadithdefcmd{bukhari}{6908}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ هِشَامٍ، عَنْ أَبِيهِ، أَنْ عُمَرَ، نَشَدَ النَّاسَ مَنْ سَمِعَ النَّبِيَّ صلى الله عليه وسلم قَضَى فِي السِّقْطِ وَقَالَ الْمُغِيرَةُ أَنَا سَمِعْتُهُ قَضَى فِيهِ بِغُرَّةٍ عَبْدٍ أَوْ أَمَةٍ‏.‏ قَالَ ائْتِ مَنْ يَشْهَدُ مَعَكَ عَلَى هَذَا فَقَالَ مُحَمَّدُ بْنُ مَسْلَمَةَ أَنَا أَشْهَدُ عَلَى النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ هَذَا‏.‏\hadithno{6908}\hadithtrans{Narrated Hisham's father: 'Umar asked the people, "Who heard the Prophet (ﷺ) giving his verdict regarding abortions?" Al-Mughira said, "I heard him judging that a male or female slave should be given (as a Diya)." 'Umar said, "Present a witness to testify your statement." Muhammad bin Maslama said, "I testify that the Prophet (ﷺ) gave such a judgment}}
\hadithdefcmd{bukhari}{6908p2}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ سَابِقٍ، حَدَّثَنَا زَائِدَةُ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ الْمُغِيرَةَ بْنَ شُعْبَةَ، يُحَدِّثُ عَنْ عُمَرَ، أَنَّهُ اسْتَشَارَهُمْ فِي إِمْلاَصِ الْمَرْأَةِ مِثْلَهُ‏.‏\hadithno{6908.2}\hadithtrans{Narrated `Urwa:I heard Al-Maghira bin Shu`ba narrating that `Umar had consulted them about the case of abortion (similarly as narrated in No)}}
\hadithdefcmd{bukhari}{6909}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ،‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى فِي جَنِينِ امْرَأَةٍ مِنْ بَنِي لِحْيَانَ بِغُرَّةٍ عَبْدٍ أَوْ أَمَةٍ‏.‏ ثُمَّ إِنَّ الْمَرْأَةَ الَّتِي قَضَى عَلَيْهَا بِالْغُرَّةِ تُوُفِّيَتْ، فَقَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّ مِيرَاثَهَا لِبَنِيهَا وَزَوْجِهَا، وَأَنَّ الْعَقْلَ عَلَى عَصَبَتِهَا‏.‏\hadithno{6909}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) gave a verdict regarding an aborted fetus of a woman from Bani Lihyan that the killer (of the fetus) should give a male or female slave (as a Diya) but the woman who was required to give the slave, died, so Allah's Messenger (ﷺ) gave the verdict that her inheritance be given to her children and her husband and the Diya be paid by her 'Asaba}}
\hadithdefcmd{bukhari}{6910}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ اقْتَتَلَتِ امْرَأَتَانِ مِنْ هُذَيْلٍ، فَرَمَتْ إِحْدَاهُمَا الأُخْرَى بِحَجَرٍ قَتَلَتْهَا وَمَا فِي بَطْنِهَا، فَاخْتَصَمُوا إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَضَى أَنَّ دِيَةَ جَنِينِهَا غُرَّةٌ عَبْدٌ أَوْ وَلِيدَةٌ، وَقَضَى دِيَةَ الْمَرْأَةِ عَلَى عَاقِلَتِهَا‏.‏\hadithno{6910}\hadithtrans{Narrated Abu Huraira:Two women from Hudhail fought with each other and one of them hit the other with a stone that killed her and what was in her womb. The relatives of the killer and the relatives of the victim submitted their case to the Prophet (ﷺ) who judged that the Diya for the fetus was a male or female slave, and the Diya for the killed woman was to be paid by the 'Asaba (near relatives) of the killer}}
\hadithdefcmd{bukhari}{6911}{حَدَّثَنِي عَمْرُو بْنُ زُرَارَةَ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ أَخَذَ أَبُو طَلْحَةَ بِيَدِي فَانْطَلَقَ بِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أَنَسًا غُلاَمٌ كَيِّسٌ فَلْيَخْدُمْكَ‏.‏ قَالَ فَخَدَمْتُهُ فِي الْحَضَرِ وَالسَّفَرِ، فَوَاللَّهِ مَا قَالَ لِي لِشَىْءٍ صَنَعْتُهُ، لِمَ صَنَعْتَ هَذَا هَكَذَا وَلاَ لِشَىْءٍ لَمْ أَصْنَعْهُ لِمَ لَمْ تَصْنَعْ هَذَا هَكَذَا\hadithno{6911}\hadithtrans{Narrated `Abdul-`Aziz:Anas said, "When Allah's Messenger (ﷺ) arrived at Medina, Abu Talha took hold of my hand and brought me to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! Anas is an intelligent boy, so let him serve you." Anas added, "So I served the Prophet (ﷺ) L at home and on journeys; by Allah, he never said to me for anything which I did: Why have you done this like this or, for anything which I did not do: 'Why have you not done this like this?}}
\hadithdefcmd{bukhari}{6912}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْعَجْمَاءُ جُرْحُهَا جُبَارٌ، وَالْبِئْرُ جُبَارٌ، وَالْمَعْدِنُ جُبَارٌ، وَفِي الرِّكَازِ الْخُمُسُ ‏"‏‏.‏\hadithno{6912}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "There is no Diya for persons killed by animals or for the one who has been killed accidentally by falling into a well or for the one killed in a mine. And one-fifth of Rikaz (treasures buried before the Islamic era) is to be given to the state}}
\hadithdefcmd{bukhari}{6913}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعَجْمَاءُ عَقْلُهَا جُبَارٌ، وَالْبِئْرُ جُبَارٌ، وَالْمَعْدِنُ جُبَارٌ، وَفِي الرِّكَازِ الْخُمُسُ ‏"‏‏.‏\hadithno{6913}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "There is no Diya for a person injured or killed by an animal (going about without somebody to control it) and similarly, there is no Diya for the one who falls and dies in a well, and also the one who dies in a mine. As regards the Ar-Rikaz (buried wealth), one-fifth thereof is for the state}}
\hadithdefcmd{bukhari}{6914}{حَدَّثَنَا قَيْسُ بْنُ حَفْصٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الْحَسَنُ، حَدَّثَنَا مُجَاهِدٌ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَتَلَ نَفْسًا مُعَاهَدًا لَمْ يَرَحْ رَائِحَةَ الْجَنَّةِ، وَإِنَّ رِيحَهَا يُوجَدُ مِنْ مَسِيرَةِ أَرْبَعِينَ عَامًا ‏"‏‏.‏\hadithno{6914}\hadithtrans{Narrated `Abdullah bin `Amr:The Prophet (ﷺ) said, "Whoever killed a Mu'ahid (a person who is granted the pledge of protection by the Muslims) shall not smell the fragrance of Paradise though its fragrance can be smelt at a distance of forty years (of traveling)}}
\hadithdefcmd{bukhari}{6915}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا مُطَرِّفٌ، أَنَّ عَامِرًا، حَدَّثَهُمْ عَنْ أَبِي جُحَيْفَةَ، قَالَ قُلْتُ لِعَلِيٍّ‏.‏ وَحَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، حَدَّثَنَا مُطَرِّفٌ، سَمِعْتُ الشَّعْبِيَّ، يُحَدِّثُ قَالَ سَمِعْتُ أَبَا جُحَيْفَةَ، قَالَ سَأَلْتُ عَلِيًّا ـ رضى الله عنه ـ هَلْ عِنْدَكُمْ شَىْءٌ مِمَّا لَيْسَ فِي الْقُرْآنِ ـ وَقَالَ ابْنُ عُيَيْنَةَ مَرَّةً مَا لَيْسَ عِنْدَ النَّاسِ ـ فَقَالَ وَالَّذِي فَلَقَ الْحَبَّةَ وَبَرَأَ النَّسَمَةَ مَا عِنْدَنَا إِلاَّ مَا فِي الْقُرْآنِ إِلاَّ فَهْمًا يُعْطَى رَجُلٌ فِي كِتَابِهِ وَمَا فِي الصَّحِيفَةِ‏.‏ قُلْتُ وَمَا فِي الصَّحِيفَةِ قَالَ الْعَقْلُ، وَفِكَاكُ الأَسِيرِ، وَأَنْ لاَ يُقْتَلَ مُسْلِمٌ بِكَافِرٍ‏.‏\hadithno{6915}\hadithtrans{Narrated Abu Juhaifa:I asked `Ali "Do you have anything Divine literature besides what is in the Qur'an?" Or, as Uyaina once said, "Apart from what the people have?" `Ali said, "By Him Who made the grain split (germinate) and created the soul, we have nothing except what is in the Qur'an and the ability (gift) of understanding Allah's Book which He may endow a man, with and what is written in this sheet of paper." I asked, "What is on this paper?" He replied, "The legal regulations of Diya (Blood-money) and the (ransom for) releasing of the captives, and the judgment that no Muslim should be killed in Qisas (equality in punishment) for killing a Kafir (disbeliever)}}
\hadithdefcmd{bukhari}{6916}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُخَيِّرُوا بَيْنَ الأَنْبِيَاءِ ‏"‏‏.‏\hadithno{6916}\hadithtrans{Narrated Abu Sa`id:The Prophet (ﷺ) said, "Do not prefer some prophets to others}}
\hadithdefcmd{bukhari}{6917}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ جَاءَ رَجُلٌ مِنَ الْيَهُودِ إِلَى النَّبِيِّ صلى الله عليه وسلم قَدْ لُطِمَ وَجْهُهُ فَقَالَ يَا مُحَمَّدُ إِنَّ رَجُلاً مِنْ أَصْحَابِكَ مِنَ الأَنْصَارِ لَطَمَ فِي وَجْهِي‏.‏ قَالَ ‏"‏ ادْعُوهُ ‏"‏‏.‏ فَدَعَوْهُ‏.‏ قَالَ ‏"‏ لِمَ لَطَمْتَ وَجْهَهُ ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ إِنِّي مَرَرْتُ بِالْيَهُودِ فَسَمِعْتُهُ يَقُولُ وَالَّذِي اصْطَفَى مُوسَى عَلَى الْبَشَرِ‏.‏ قَالَ قُلْتُ وَعَلَى مُحَمَّدٍ صلى الله عليه وسلم قَالَ فَأَخَذَتْنِي غَضْبَةٌ فَلَطَمْتُهُ‏.‏ قَالَ ‏"‏ لاَ تُخَيِّرُونِي مِنْ بَيْنِ الأَنْبِيَاءِ فَإِنَّ النَّاسَ يَصْعَقُونَ يَوْمَ الْقِيَامَةِ فَأَكُونُ أَوَّلَ مَنْ يُفِيقُ، فَإِذَا أَنَا بِمُوسَى آخِذٌ بِقَائِمَةٍ مِنْ قَوَائِمِ الْعَرْشِ، فَلاَ أَدْرِي أَفَاقَ قَبْلِي أَمْ جُزِيَ بِصَعْقَةِ الطُّورِ ‏"‏‏.‏\hadithno{6917}\hadithtrans{Narrated Abu Sa`id Al-Khudri:A Jew whose face had been slapped (by someone), came to the Prophet (ﷺ) and said, "O Muhammad! A man from your Ansari companions slapped me. " The Prophet (ﷺ) said, "Call him". They called him and the Prophet (ﷺ) asked him, "Why did you slap his face?" He said, "O Allah's Messenger (ﷺ)! While I was passing by the Jews, I heard him saying, 'By Him Who chose Moses above all the human beings.' I said (protestingly), 'Even above Muhammad?' So I became furious and slapped him." The Prophet (ﷺ) said, "Do not give me preference to other prophets, for the people will become unconscious on the Day of Resurrection and I will be the first to gain conscious, and behold, I will Find Moses holding one of the pillars of the Throne (of Allah). Then I will not know whether he has become conscious before me or he has been exempted because of his unconsciousness at the mountain (during his worldly life) which he received}}
